==> w3css_paragraphs-1.0.14.tar.gz: w3css_paragraphs/modules/w3css_paragraphs_accordion/js/w3css-paragraphs-accordion.js <==
/**
 * @file
 * W3CSS Paragraphs Accordion.
 *
 * Filename:     w3css-paragraphs-accordion.js
 * Website:      https://www.flashwebcenter.com
 * Developer:    Alaa Haddad https://www.alaahaddad.com.
 */
(function ($, Drupal, once) {
  'use strict';
  Drupal.behaviors.w3cssParagraphsAccordion = {
    attach: function (settings) {

      // work around big pipe https://www.drupal.org/node/2794099
      // https://drupal.stackexchange.com/a/314250
      // https://www.drupal.org/project/drupal/issues/3272693
      var charging_blocs = $('[data-big-pipe-placeholder-id]').length;
      if (!charging_blocs ){

        // Accordion
        // Global helper
        function getMyId(classId) {
          const myIds = [];
          myIds[0] = document.querySelectorAll("#" + classId + ">.wrapper-accs-btn-pane");
          myIds[1] = document.querySelector("#" + classId + ">.ex-button>button.minus");
          myIds[2] = document.querySelector("#" + classId + ">.ex-button>button.plus");
          return myIds;
        }
        $(once('.w3-accs-button', '.w3-accs-button>button')).on('click', function () {
          let listClass, classId, sectionId, x;
          classId = $(this).parent().parent().attr('id');
          sectionId = $(this).parent().parent().parent().attr('id');
          x = getMyId(sectionId);
          listClass = document.getElementById(classId).classList;
          // Open
          if (listClass.contains('w3-not-active')) {
            document.getElementById(classId).className = document.getElementById(classId).className.replace("w3-not-active", "w3-is-active");
            $('#' + sectionId).each(function () {
              if (!$(this).children('.w3-not-active').length) {
                x[1].style.display = "block";
                x[2].style.display = "none";
              }
            });
          } else {
            // close
            document.getElementById(classId).className = document.getElementById(classId).className.replace("w3-is-active", "w3-not-active");
            $('#' + sectionId).each(function () {
              if (!$(this).children('.w3-is-active').length) {
                if (x[2]) {
                  x[2].style.display = "block";
                  x[1].style.display = "none";
                }
              }
            });
          }
        });
        $(once('.ex-button', '.ex-button>button.plus')).on('click', function () {
          let classId, s;
          classId = $(this).parent().parent().attr('id');
          s = getMyId(classId);
          for (let j = 0; j < s[0].length; j++) {
            s[0][j].className = s[0][j].className.replace("w3-not-active", "w3-is-active");
          }
          s[2].style.display = "none";
          s[1].style.display = "block";
        });
        $(once('.ex-button', '.ex-button>button.minus')).on('click', function () {
          let classId, s;
          classId = $(this).parent().parent().attr('id');
          s = getMyId(classId);
          for (let j = 0; j < s[0].length; j++) {
            s[0][j].className = s[0][j].className.replace("w3-is-active", "w3-not-active");
          }
          s[1].style.display = "none";
          s[2].style.display = "block";
        });
      }
    }
  }
})(jQuery, Drupal, once);

==> w3css_paragraphs-1.0.15.tar.gz: w3css_paragraphs/modules/w3css_paragraphs_accordion/js/w3css-paragraphs-accordion.js <==
/**
 * @file
 * W3CSS Paragraphs Accordion.
 *
 * Filename:     w3css-paragraphs-accordion.js
 * Website:      https://www.flashwebcenter.com
 * Developer:    Alaa Haddad https://www.alaahaddad.com.
 */
(function ($, Drupal, once) {
  'use strict';
  Drupal.behaviors.w3cssParagraphsAccordion = {
    attach: function (context, settings) {

        function getMyId(classId) {
          const myIds = [];
          myIds[0] = context.querySelectorAll("#" + classId + ">.wrapper-accs-btn-pane");
          myIds[1] = context.querySelector("#" + classId + ">.ex-button>button.minus");
          myIds[2] = context.querySelector("#" + classId + ">.ex-button>button.plus");
          return myIds;
        }

        $(once('.w3-accs-button', '.w3-accs-button>button')).on('click', function () {
          let listClass, classId, sectionId, x;
          classId = $(this).parent().parent().attr('id');
          sectionId = $(this).parent().parent().parent().attr('id');
          x = getMyId(sectionId);
          listClass = context.getElementById(classId).classList;
          // Open
          if (listClass.contains('w3-not-active')) {
            context.getElementById(classId).className = context.getElementById(classId).className.replace("w3-not-active", "w3-is-active");
            $('#' + sectionId).each(function () {
              if (!$(this).children('.w3-not-active').length) {
                x[1].style.display = "block";
                x[2].style.display = "none";
              }
            });
          } else {
            // close
            context.getElementById(classId).className = context.getElementById(classId).className.replace("w3-is-active", "w3-not-active");
            $('#' + sectionId).each(function () {
              if (!$(this).children('.w3-is-active').length) {
                if (x[2]) {
                  x[2].style.display = "block";
                  x[1].style.display = "none";
                }
              }
            });
          }
        });

        $(once('.ex-button', '.ex-button>button.plus')).on('click', function () {
          let classId, s;
          classId = $(this).parent().parent().attr('id');
          s = getMyId(classId);
          for (let j = 0; j < s[0].length; j++) {
            s[0][j].className = s[0][j].className.replace("w3-not-active", "w3-is-active");
          }
          s[2].style.display = "none";
          s[1].style.display = "block";
        });

        $(once('.ex-button', '.ex-button>button.minus')).on('click', function () {
          let classId, s;
          classId = $(this).parent().parent().attr('id');
          s = getMyId(classId);
          for (let j = 0; j < s[0].length; j++) {
            s[0][j].className = s[0][j].className.replace("w3-is-active", "w3-not-active");
          }
          s[1].style.display = "none";
          s[2].style.display = "block";
        });

      }
  }
})(jQuery, Drupal, once);
